#
# spec file for package libpmemobj-cpp
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libpmemobj-cpp
%define lname   libpmemobj-cpp0
Version:        1.13.0
Release:        1.8
Summary:        C++ bindings for libpmemobj
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            http://pmem.io/pmdk/
Source:         https://github.com/pmem/libpmemobj-cpp/archive/%version.tar.gz
Patch1:         0001-Fix-compliation-on-gcc-12.patch
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(libpmemobj) >= 1.8
ExclusiveArch:  x86_64 aarch64 ppc64le

%description
There are three main features of the C++ bindings to libpmemobj:

  * the `persistent_ptr<>` smart pointer,
  * the `transaction`, which comes in two flavours - scoped and closure,
  * the `p<>` property.

The main issue with the C API is a large set of macros and difficulty
in manual usage of `setjmp`.

%package devel
Summary:        C++ bindings for libpmemobj
Group:          Development/Libraries/C and C++
Obsoletes:      libpmemobj++-devel < %version
Provides:       libpmemobj++-devel = %version

%description devel
This package contains the header files for pmemobj's C++ interface.

%package devel-doc
Summary:        Example C++ programs for libpmemobj++
Group:          Documentation/Other

%description devel-doc
Example C++ programs (with source) on how to use libpmemobj++.

%prep
%autosetup -p1

%build
%cmake \
%if 0%{?suse_version} < 1500
	-DTEST_ARRAY=OFF -DTEST_VECTOR=OFF -DTEST_STRING=OFF \
	-DTEST_CONCURRENT_HASHMAP=OFF -DTEST_SEGMENT_VECTOR_ARRAY_EXPSIZE=OFF \
	-DTEST_SEGMENT_VECTOR_VECTOR_EXPSIZE=OFF \
	-DTEST_SEGMENT_VECTOR_VECTOR_FIXEDSIZE=OFF \
	-DTEST_ENUMERABLE_THREAD_SPECIFIC=OFF \
%endif
	-DTESTS_USE_VALGRIND:BOOL=OFF \
	-DCMAKE_INSTALL_DOCDIR="%_docdir/%name"
%cmake_build

%install
%cmake_install

%files devel
%license LICENSE
%doc ChangeLog
%_includedir/libpmemobj++/
%_libdir/libpmemobj++/
%_libdir/pkgconfig/*.pc

%files devel-doc
%_docdir/%name/

%changelog
* Wed May 25 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.13.0
  * Introduce experimental MPSC queue
    (pmem::obj::experimental::mpsc_queue)
  * Implement support for multi-reader single-writer concurrency
    in pmem::obj::experimental::radix_tree
  * Introduce basic_dram_inline_string which can be kept both on
    pmem and dram
  * Bug fixes:
  * Fix radix_tree leaf layout to ensure proper key/value alignment
- Add 0001-Fix-compliation-on-gcc-12.patch
* Fri Jan 22 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Enable aarch64 build
* Mon Oct 26 2020 Christian Vögl <christian.voegl@suse.com>
- Update to version 1.11
  * experimental radix_tree container (single-threaded sorted map)
  * experimental inline_string class (class serves similar
    purpose to pmem::obj::string, but keeps the data within the
    same allocation as inline_string itself)
  * string_view class (support for compilers older than C++17)
  * experimental self_relative_ptr and
    std::atomic<self_relative_ptr> specialization (persistent
    smart ptr which encapsulates the self offseted pointer and
    provides member access, dereference and array access
    operators - for some workloads it could be faster alternative
    for persistent_ptr)
  * optimizations for concurrent_map with self_relative_ptr
  * missing constructors for basic_string class
  * conversion operator for basic_string class
  * ported libcxx's sorted map tests
  * lower and lower_eq methods for concurrent_map
  * missing constructor for concurrent_map (comparator as an
    argument)
* Tue Sep 15 2020 Christian Vögl <christian.voegl@suse.com>
- This version is needed for pmemkv (jsc#SLE-13670)
* Tue Aug 18 2020 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Enable build for ppc64le
* Tue Jun  2 2020 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to version 1.10
  * New experimental container type "concurrent_map", a
    persistent concurrent map (based on concurrent skiplist
    implementation).
  * swap() method for basic_string
- Drop Add-support-for-older-cmake.patch fixed upstream
* Thu Feb 13 2020 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to version 1.9
  - segment_vector has graduated out of experiment.
  - new methods for pmem::obj::string (find() and its overloads)
  - defragmentation feature as a separate class in pmem::obj namespace and
    support for the defragmentation in containers: concurrent_hash_map,
    vector, string
  - removed template parameters from persistent_ptr_base class (make it
    type agnostic) and moved to the public API
  - new methods for pmem::obj::concurrent_hash_map (insert_or_assign and
    its overloads)
- Add Add-support-for-older-cmake.patch for compatibility with older cmake versions
- Disable tests for older GCC with incomplete c++14 support
* Fri Oct 11 2019 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to version 1.8 (jsc#SLE-9886)
  - array/vector/string/concurrent_hash_map have graduated out of experiment.
    They are now guaranteed to have a stable API
  - See ChangeLog for a list of all fixes
* Tue May 28 2019 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Disable experimental array/vector/string for older releases as
  GCC doesn't fully support the required C++11 extensions.
* Mon May 13 2019 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to version 1.6 (jsc#6358)
  - See ChangeLog for the complete change list
* Wed Feb  6 2019 nmoreychaisemartin@suse.com
- Conflict with former libpmemobj++-devel (bsc#1124441)
* Tue Nov  6 2018 Jan Engelhardt <jengelh@inai.de>
- C++ bindings have been split off pmdk to a separate package
  (libpmemobj-cpp), version 1.5
